#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'wav2bin'
DESCRIPTION = "Program to be used concurrently with Dennis Kodimer's CEC 222 lab."
URL = 'https://github.com/jvanderen1/Kodimer_Project'
EMAIL = 'jvanderen1@gmail.com'
AUTHOR = 'Joshua Van Deren'

# What packages are required for this module to be executed?
REQUIRED = [
            'matplotlib',
            'numpy',
            'scipy'
            ]

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    LONG_DESCRIPTION = '\n' + f.read()

# Load the package's __version__.py module as a dictionary.
about = {}
with open(os.path.join(here, NAME, '__version__.py')) as f:
    exec(f.read(), about)


class UploadCommand(Command):
    """Support setup.py upload."""
    
    description = 'Build and publish the package.'
    user_options = []
    
    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))
    
    def initialize_options(self):
        pass
    
    def finalize_options(self):
        pass
    
    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass
        
        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))
        
        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')
        
        sys.exit()


# Where the magic happens:
setup(
      name=NAME,
      version=about['__version__'],
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      author=AUTHOR,
      author_email=EMAIL,
      url=URL,
      packages=['wav2bin', 'wav2bin.src'],
      # If your package is a single module, use this instead of 'packages':
      # py_modules=['mypackage'],
      
      entry_points={
        'gui_scripts': [
                'wav2bin = wav2bin.src.__main__:main'
        ]
      },
      install_requires=REQUIRED,
      python_requires='>=3',
      include_package_data=True,
      license='MIT',
      classifiers=[
                   # Trove classifiers
                   # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
                   'License :: OSI Approved :: MIT License',
                   'Programming Language :: Python :: 3 :: Only',
                   'Natural Language :: English',
                   'Topic :: Scientific/Engineering :: Human Machine Interfaces',
                   'Topic :: Software Development :: User Interfaces'
                   ],
      # $ setup.py publish support.
      cmdclass={
        'upload': UploadCommand,
      },
)
